<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>MX Package Installer</source>
        <translation>MX Paket Kurucusu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Gözde Uygulamalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="468"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="1030"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="730"/>
        <location filename="../mainwindow.ui" line="1055"/>
        <location filename="../mainwindow.ui" line="1274"/>
        <source>search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="772"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>= Installed packages</source>
        <translation>= Kurulu paketler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Enabled Repos</source>
        <translation>Etkin Depolar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Remove orphan packages</source>
        <translation>Yetim paketleri kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <location filename="../mainwindow.ui" line="1337"/>
        <source>Upgrade All</source>
        <translation>Hepsini Yükselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.ui" line="558"/>
        <location filename="../mainwindow.ui" line="886"/>
        <source>Installed:</source>
        <translation>Kurulu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="907"/>
        <source>Total packages:</source>
        <translation>Toplam paket sayısı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="615"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Ayrıca &quot;Önerilen&quot; Paketleri Kur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="879"/>
        <source>Upgradable:</source>
        <translation>Yükseltilebilir:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <location filename="../mainwindow.ui" line="522"/>
        <location filename="../mainwindow.ui" line="914"/>
        <source>Hide library and developer packages</source>
        <translation>Kütüphane ve geliştirici paketlerini gizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Refresh list</source>
        <translation>Listeyi Yenile</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <location filename="../mainwindow.ui" line="688"/>
        <location filename="../mainwindow.ui" line="1085"/>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paketleri durumlarına göre süzün.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <location filename="../mainwindow.ui" line="397"/>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="695"/>
        <location filename="../mainwindow.ui" line="1088"/>
        <location filename="../mainwindow.ui" line="1092"/>
        <location filename="../mainwindow.cpp" line="2645"/>
        <source>All packages</source>
        <translation>Tüm paketler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <location filename="../mainwindow.ui" line="700"/>
        <location filename="../mainwindow.ui" line="1097"/>
        <location filename="../mainwindow.cpp" line="2657"/>
        <source>Installed</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <location filename="../mainwindow.ui" line="705"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <location filename="../mainwindow.cpp" line="2656"/>
        <source>Upgradable</source>
        <translation>Yükseltilebilir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1107"/>
        <location filename="../mainwindow.ui" line="1234"/>
        <location filename="../mainwindow.cpp" line="2625"/>
        <location filename="../mainwindow.cpp" line="2658"/>
        <location filename="../mainwindow.cpp" line="2773"/>
        <location filename="../mainwindow.cpp" line="2774"/>
        <source>Not installed</source>
        <translation>Kurulu değil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <location filename="../mainwindow.ui" line="752"/>
        <location filename="../mainwindow.ui" line="814"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Yükseltilebilir paket. Seçilen depoda daha yeni sürüm mevcut.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Package Name</source>
        <translation>Paket Adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <location filename="../mainwindow.ui" line="1469"/>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>MX Test Deposu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="796"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1142"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1148"/>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>For all users</source>
        <translation>Tüm kullanıcılar için</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>For current user</source>
        <translation>Şu anki kullanıcı için</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Remote (repo):</source>
        <translation>Uzak (depo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.ui" line="1204"/>
        <location filename="../mainwindow.cpp" line="2605"/>
        <source>All apps</source>
        <translation>Tüm uygulamalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.cpp" line="2610"/>
        <source>All runtimes</source>
        <translation>Tüm çalışma zamanları</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1214"/>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>All available</source>
        <translation>Hepsi mevcut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1219"/>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>Installed apps</source>
        <translation>Kurulu uygulamalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <location filename="../mainwindow.cpp" line="2601"/>
        <source>Installed runtimes</source>
        <translation>Yüklü çalışma zamanları</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1229"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <location filename="../mainwindow.cpp" line="2766"/>
        <location filename="../mainwindow.cpp" line="2767"/>
        <source>All installed</source>
        <translation>Hepsi yüklendi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1316"/>
        <source>Total items </source>
        <translation>Toplam öğe sayısı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1330"/>
        <source>Installed apps:</source>
        <translation>Kurulu uygulamalar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1413"/>
        <source>Total installed size:</source>
        <translation>Toplam kurulu büyüklük:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1427"/>
        <source>Remove unused runtimes</source>
        <translation>Kullanılmayan runtime paketlerini kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1459"/>
        <source>Short Name</source>
        <translation>Kısa Adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1464"/>
        <source>Full Package Name</source>
        <translation>Tam Paket Adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1504"/>
        <location filename="../mainwindow.cpp" line="2390"/>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>Console Output</source>
        <translation>Uçbirim Çıktısı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1510"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1521"/>
        <source>Respond here, or just press Enter</source>
        <translation>Burada cevaplayın veya sadece Enter’a basın</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1580"/>
        <location filename="../mainwindow.cpp" line="1101"/>
        <location filename="../mainwindow.cpp" line="2760"/>
        <location filename="../mainwindow.cpp" line="2763"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1587"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1606"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1609"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1616"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1696"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1706"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1722"/>
        <source>Uninstall</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1729"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Flatpak tab is disabled on 32-bit.</source>
        <translation>Flatpak sekmesi 32-bit’te devre dışıdır.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Could not find MX sources.</source>
        <translation>MX kaynakları bulunamadı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Uninstalling packages...</source>
        <translation>Paketler kaldırılıyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Kaldırma öncesi işlemler çalıştırılıyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Running post-uninstall operations...</source>
        <translation>Kaldırma sonrası işlemler çalıştırılıyor ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <source>Refreshing sources...</source>
        <translation>Kaynaklar yenileniyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <location filename="../mainwindow.cpp" line="1149"/>
        <location filename="../mainwindow.cpp" line="1278"/>
        <location filename="../mainwindow.cpp" line="1430"/>
        <location filename="../mainwindow.cpp" line="1493"/>
        <location filename="../mainwindow.cpp" line="1805"/>
        <location filename="../mainwindow.cpp" line="1929"/>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2255"/>
        <location filename="../mainwindow.cpp" line="2366"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2439"/>
        <location filename="../mainwindow.cpp" line="2467"/>
        <location filename="../mainwindow.cpp" line="2487"/>
        <location filename="../mainwindow.cpp" line="2851"/>
        <location filename="../mainwindow.cpp" line="2925"/>
        <location filename="../mainwindow.cpp" line="2955"/>
        <location filename="../mainwindow.cpp" line="3050"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Kaynaklar güncellenirken bir sorun oluştu. Bazı kaynaklar güncellenmemiş olabilir. Daha fazla bilgi için:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Please wait...</source>
        <translation>Lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>Version </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source> in the enabled repos</source>
        <translation>etkin depolarda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Not available in the enabled repos</source>
        <translation>Etkin depolarda mevcut değil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Latest version </source>
        <translation>En son sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source> already installed</source>
        <translation>zaten kurulu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source> installed</source>
        <translation>kuruldu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Paketleri yalnızca deneme amacıyla sağlanan MX Test deposunu kullanmak üzeresiniz. Sisteminizi bozma olasılığı vardır, bu nedenle sisteminizi yedeklemeniz ve bir seferde yalnızca bir paketi yüklemeniz veya güncellemeniz önerilir. Lütfen Forum’da geri bildirimde bulunun, böylece paket Ana Depoya geçmeden önce değerlendirilebilir.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Bir sonraki Debian sürümünden (‘testing’ olarak adlandırılır) alınan paketleri içeren Debian Backports’u kullanmak üzeresiniz. Debian kararlı sürümünde kullanılmak üzere ayarlanmış ve yeniden derlenmiştir. Debian ve antiX Linux’un kararlı sürümlerinde olduğu gibi kapsamlı bir şekilde test edilememekteler ve Debian Kararlı Sürümdeki diğer bileşenlerle uyumsuzluk riskiyle beraber &quot;oldukları gibi&quot; sağlanmaktalar. Dikkatli kullanın!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="991"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux, yalnızca kullanıcıların rahatlığı için flatpaks deposunu içerir ve bireysel flatpaks’ların işlevselliğinden sorumlu değildir. Daha fazla bilgi için Wiki’deki flatpaks’e bakın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="999"/>
        <location filename="../mainwindow.cpp" line="3059"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Do not show this message again</source>
        <translation>Bu iletiyi tekrar gösterme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Aşağıdaki paketler seçildi. Değişikliklerin listesi için Ayrıntıları Göster’e tıklayın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1150"/>
        <location filename="../mainwindow.cpp" line="1279"/>
        <location filename="../mainwindow.cpp" line="1494"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>İnternete bağlı değilsiniz, paket listesi indirilemeyecek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1153"/>
        <source>Installing packages...</source>
        <translation>Paketler kuruluyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1208"/>
        <source>Post-processing...</source>
        <translation>Son işlem...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1240"/>
        <source>Pre-processing for </source>
        <translation>Ön işlemi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1255"/>
        <source>Installing </source>
        <translation>Kuruluyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>Post-processing for </source>
        <translation>Son işlemi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Dosya yazılırken bir hata oluştu: %1. Lütfen sürücünüzde yeterli boş alan olup olmadığını kontrol edin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1502"/>
        <source>Downloading package info...</source>
        <translation>Paket bilgisi indiriliyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <location filename="../mainwindow.cpp" line="1930"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2005"/>
        <location filename="../mainwindow.cpp" line="2087"/>
        <location filename="../mainwindow.cpp" line="2110"/>
        <source>Package info</source>
        <translation>Paket bilgisi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2017"/>
        <location filename="../mainwindow.cpp" line="2992"/>
        <source>More &amp;info...</source>
        <translation>Daha fazla b&amp;ilgi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2048"/>
        <source>Packages to be installed: </source>
        <translation>Kurulacak paketler:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <source>Done</source>
        <translation>Tamamlandı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Processing finished successfully.</source>
        <translation>İşlem Başarıyla Sonuçlandı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2244"/>
        <location filename="../mainwindow.cpp" line="2256"/>
        <location filename="../mainwindow.cpp" line="2852"/>
        <location filename="../mainwindow.cpp" line="2926"/>
        <location filename="../mainwindow.cpp" line="2956"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Kurulum sırasında bir hata saptandı, lütfen uçbirim çıktısını kontrol edin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2266"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2267"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2269"/>
        <source>Package Installer for MX Linux</source>
        <translation>MX Linux için Paket Kurucu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2271"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2272"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2284"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2366"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Kaldırma işlemi sırasında bir sorunla karşılaştık, lütfen çıktıyı kontrol edin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>programı kaldırırken bir hata ile karşılaştık.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2440"/>
        <location filename="../mainwindow.cpp" line="2468"/>
        <location filename="../mainwindow.cpp" line="2488"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Paket listesi indirilemedi. Lütfen APT kaynaklarınızı kontrol edin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2520"/>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak kurulu değil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2521"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak şu anda yüklü değil.
Devam edip yüklensin mi?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak kurulmadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2558"/>
        <source>Needs re-login</source>
        <translation>Yeniden giriş gerekiyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2559"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Menüdeki yüklü öğeleri görmek için oturumu kapatıp açmanız gerekebilir.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2760"/>
        <source>Upgrade</source>
        <translation>Yükselt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2880"/>
        <source>Quit?</source>
        <translation>Vazgeçilsin mi?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2881"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>İşlem devam ediyor, vazgeçmek sistemi kararsız duruma getirebilir. &lt;p&gt;&lt;b&gt;MX paket kurucudan çıkmak istediğinizden emin misiniz?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3026"/>
        <source>Reinstall</source>
        <translation>Yeniden kur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3051"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Son işlem sırasında sorun algılandı, lütfen konsol çıktısını kontrol edin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3060"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Potansiyel tehlikeli işlem.
Lütfen kaldırılacak paketlerin listesini dikkatlice kontrol ettiğinizden emin olun.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Flatpak Uzaktan Yönetme</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Tüm kullanıcılar için</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Şu anki kullanıcı için</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>Flatpak uzak adresi girin</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>uygulamayı yüklemek için Flatpakref konumunu girin</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Flatpak uzak depolarını ekleyin, kaldırın veya flatpakref adresini, yolunu kullanarak uygulamaları yükleyin</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Uzaktan kumandayı kaldır</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Uzaktan kumanda ekle</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Uygulamayı yükle</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Çıkarılabilir değil</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub ana uzak Flatpak depodur ve kaldırılmayacaktır</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="95"/>
        <source>Error adding remote</source>
        <translation>Uzaktakini ekleme başarısız</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Uzaktan komut eklenemedi bir hata olarak döndü. Lütfen uzak adresi iki kez kontrol edin ve tekrar deneyin</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>Uzaktaki başarıyla eklendi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Dpkg/apt veritabanı başka bir program tarafından kilitlendi: %1
Programı kapatın veya işlemin tamamlanmasını bekleyip tekrar deneyin.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Paket Yükleyici, MX Linux’ta paketleri yönetmek için kullanılan bir araçtır 
    - farklı kaynaklardan popüler programları yükler 
    - MX Test deposundan programları yükler 
    - Debian Backports deposundan programları yükler 
    - flatpak’ları yükler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Yanlışlıkla internet erişimi olmadığını bildiriyorsa çevrimiçi kontrolü atlayın.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <location filename="../main.cpp" line="103"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Görünüşe göre root olarak girmişsiniz, lütfen çıkın ve bu programı kullanmak için normal kullanıcı olarak girin. </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>You must run this program with admin access.</source>
        <translation>Bu programı yönetici erişimiyle çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
